-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

--round from http://lua-users.org/wiki/SimpleRound


local M = {}

local fuelCapacity, speed, rpm, gear, fuel, water, boost
local brake0, brake1, brake2, brake3
local maxRpm, rpmC, rpmUp, rpmDn
local wasteStart, wasteLimit
local brakeFL, brakeFR, brakeRL, brakeRR

local vehicleID = obj:getID()
local dashScreenName = "@etki_screen"
local lowhighbeam = 0



local function round(num, idp)
	if num then
		local mult = 10^(idp or 0)
		return math.floor(num * mult + 0.5) / mult
	else
		return 0
	end
end



local function onInit()
	if v.data.engine.digital_gauges == true then
		obj:queueGameEngineLua("extensions.loadModule('ui/uinavi')")
		obj:queueGameEngineLua('be:getObjectByID('..vehicleID..'):createUITexture("'..dashScreenName..'", "local://local/vehicles/etki/dash_screen.html", 1024, 512, UI_TEXTURE_USAGE_AUTOMATIC, 30)')
		fuelCapacity = v.data.engine.fuelCapacity
		
		maxRpm = v.data.engine.maxRPM
		rpmUp = v.data.engine.shiftUpRPM
		rpmDn = v.data.engine.shiftDownRPM
		
		wasteStart = v.data.turbocharger.wastegateStart
		wasteLimit = v.data.turbocharger.wastegateLimit
	else
		return
	end
end

local function onReset()
    onInit()
end

local function updateGFX(dt)
	if v.data.engine.digital_gauges == true then
		
		speed = math.floor(((electrics.values.wheelspeed or 0) * 3.6) + 0.5)
		rpm = math.floor(electrics.values.rpm + 0.5)
		
		rpmP = rpm / maxRpm
		
		if rpm < rpmDn then rpmC = -1 elseif rpm > rpmUp then rpmC = 1 else rpmC = 0 end
		
		gear = math.floor(electrics.values.gear_M + 0.5)
		fuel = math.floor(electrics.values.fuel * fuelCapacity + 0.5)
		water = math.floor(electrics.values.watertemp + 0.5)
		
		
		boost = electrics.values.turboBoost 
		if boost == nil or boost < 0 then boost = 0 end
		if wasteStart and wasteLimit then boostP = round(boost / ((wasteStart + wasteLimit) / 2.16), 2) end
		if boostP > 1 then boostP = 1 end
		
		for i=0, 3 do
			curWheel = v.data.wheels[i]
			if curWheel.name == "FL" then
				brakeFL = math.floor(curWheel.brakeCoreTemperature + 0.5)
			elseif curWheel.name == "FR" then
				brakeFR = math.floor(curWheel.brakeCoreTemperature + 0.5)
			elseif curWheel.name == "RL" then
				brakeRL = math.floor(curWheel.brakeCoreTemperature + 0.5)
			else
				brakeRR = math.floor(curWheel.brakeCoreTemperature + 0.5)
			end
		end
		
		obj:queueGameEngineLua("if be:getObjectByID("..vehicleID..") then be:getObjectByID("..vehicleID.."):queueJSUITexture('"..dashScreenName.."', 'dash("..speed..","..rpm..","..rpmP..","..rpmC..","..gear..","..fuel..","..water..","..round(boost * 0.0689476, 1)..","..boostP..","..brakeFL..","..brakeFR..","..brakeRL..","..brakeRR..")') end")
	else
		return
	end
end

-- public interface
M.onInit    = onInit
M.onReset   = onReset
M.updateGFX = updateGFX

return M
